# Changelog

## [0.5.0] - 2020-02-23

- Add feeds endpoint
- Set `page-all` to false by default

## [0.4.2] - 2020-02-19

- Fix bug where a string was treated as an iterable to be joined

## [0.4.1] - 2020-02-19

- Fix bug where the routes cli used the operators API endpoint

## [0.4.0] - 2020-02-09

- Add argument for paging size
- Add option to not page over all responses

## [0.3.0] - 2020-02-09

- Add onestop_id endpoint

## [0.2.0] - 2020-02-08

- Add route stop patterns and schedule stop pairs endpoints

## [0.1.1] - 2020-02-08

- Try to fix PyPI bundle

## [0.1.0] - 2020-02-08

- Initial release on PyPI
